@@ -45,7 +45,7 @@ sub method {
     return sub {
         my $method = shift;
         my $self = shift;
-        my $response = $self->{client}->$method( "$self", @_? \@_ : undef );
+        my $response = $self->{client}->$method( "$self", @_ );
 
         if (my $content_type = $response->responseHeader('Content-Type')) {
           $content_type = parse_content_type($content_type);
@@ -89,7 +89,7 @@ REST::Cot::Generators
 
 =head1 VERSION
 
-version 0.001_3
+version 0.001_4
 
 =head1 AUTHOR
 
